@@ -5,13 +5,13 @@
 #if defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE < 199309L
 #undef _POSIX_C_SOURCE
 #endif
-#ifndef _POSIX_C_SOURCE
+#if !defined(_POSIX_C_SOURCE) && !defined(__APPLE__)
 #define _POSIX_C_SOURCE 199309L
 #endif
 
 //make sure gettimeofday is available
-#ifndef _BSD_SOURCE
-#define _BSD_SOURCE
+#ifndef _DEFAULT_SOURCE
+#define _DEFAULT_SOURCE
 #endif
 
 #if HAVE_CONFIG_H
