@@ -3,10 +3,7 @@
 #include "config.h"
 #endif
 
-#include <dune/pdelab/boilerplate/pdelab.hh>
-#include <dune/pdelab/localoperator/convectiondiffusionfem.hh>
-#include <dune/pdelab/localoperator/l2.hh>
-#include "dune/pdelab/gridfunctionspace/gridfunctionadapter.hh"
+#include <dune/pdelab.hh>
 
 // Poisson problem
 template<typename GV, typename RF>
@@ -19,6 +16,12 @@ public:
 
   Poisson () : time(0.0) {}
 
+  //! tensor diffusion constant per cell? return false if you want more than one evaluation of A per cell.
+  static constexpr bool permeabilityIsConstantPerCell()
+  {
+    return true;
+  }
+
   //! tensor diffusion coefficient
   typename Traits::PermTensorType
   A (const typename Traits::ElementType& e, const typename Traits::DomainType& x) const
