@@ -3,6 +3,9 @@
 #include <iostream>
 #include <vector>
 
+#include <dune/geometry/referenceelements.hh>
+#include <dune/geometry/quadraturerules.hh>
+
 #include <dune/grid/yaspgrid.hh>
 #include <dune/grid/io/file/vtk/subsamplingvtkwriter.hh>
 
@@ -11,18 +14,8 @@
 #include <dune/functions/gridfunctions/discreteglobalbasisfunction.hh>
 #include <dune/functions/functionspacebases/hierarchicvectorwrapper.hh>
 
-#include <dune/pdelab/adaptivity/adaptivity.hh>
-#include <dune/pdelab/gridfunctionspace/dunefunctionsgridfunctionspace.hh>
-#include <dune/pdelab/gridfunctionspace/gridfunctionspaceutilities.hh>
-#include <dune/pdelab/gridfunctionspace/interpolate.hh>
-#include <dune/pdelab/constraints/common/constraints.hh>
-#include <dune/pdelab/constraints/conforming.hh>
-#include <dune/pdelab/backend/istl.hh>
-#include <dune/pdelab/localoperator/convectiondiffusionfem.hh>
-#include <dune/pdelab/localoperator/linearelasticity.hh>
-#include <dune/pdelab/gridoperator/gridoperator.hh>
+#include <dune/pdelab.hh>
 
-#include<dune/pdelab/finiteelementmap/qkfem.hh>
 
 using namespace Dune;
 
@@ -40,7 +33,6 @@ class PoissonProblem
 : public PDELab::ConvectionDiffusionModelProblem<GridView,RangeType>
 {
 public:
-
   template<typename Element, typename Coord>
   auto f(const Element& element, const Coord& x) const
   {
@@ -52,6 +44,18 @@ public:
   {
     return PDELab::ConvectionDiffusionBoundaryConditions::Dirichlet;
   }
+
+  //! Dirichlet extension
+  template<typename E, typename X>
+  RangeType g (const E& e, const X& x) const
+  {
+    auto global = e.geometry().global(x);
+    RangeType s=0.0;
+    for (std::size_t i=0; i<global.size(); i++)
+      s+=global[i]*global[i];
+    return s;
+  }
+
 };
 
 template <int order>
@@ -78,7 +82,7 @@ void solvePoissonProblem()
   // Construct Lagrangian finite element space basis
   using GridView = typename GridType::LeafGridView;
   auto gridView = grid.leafGridView();
-  using Basis = Functions::PQkNodalBasis<GridView,order>;
+  using Basis = Functions::LagrangeBasis<GridView,order>;
   auto basis = std::make_shared<Basis>(gridView);
 
   // What precisely does this do?
@@ -123,6 +127,9 @@ void solvePoissonProblem()
   VectorContainer x0(gfs);
   x0 = 0.0;              // set all entries to zero
 
+  // Make a grid function out of it, just to check that this compiles
+  PDELab::DiscreteGridFunction<GridFunctionSpace,VectorContainer> xDiscreteGridFunction(gfs,x0);
+
   // represent operator as a matrix
   typedef typename GO::Jacobian MatrixContainer;
   MatrixContainer m(go,stiffnessMatrix);    // Use the stiffnessMatrix object for the actual storage
@@ -149,7 +156,7 @@ void solvePoissonProblem()
   MatrixAdapter<MatrixType,VectorType,VectorType> op(stiffnessMatrix);
 
   // A preconditioner
-  SeqILU0<MatrixType,VectorType,VectorType> ilu0(stiffnessMatrix,1.0);
+  SeqILU<MatrixType,VectorType,VectorType> ilu0(stiffnessMatrix,1.0);
 
   // A preconditioned conjugate-gradient solver
   CGSolver<VectorType> cg(op,ilu0,1E-4,
@@ -163,9 +170,8 @@ void solvePoissonProblem()
   cg.apply(x, rhs, statistics);
 
   // Test whether we can refine the grid and carry a function along.
-  // Of course we cannot: we haven't marked anything, and we are using
-  // YaspGrid anyway.  But let's make sure we can at least call the method.
   VectorContainer xContainer(gfs,x);
+  grid.mark(1, *grid.leafGridView().template begin<0>());
   PDELab::adapt_grid(grid, gfs, xContainer, 2 );
 
   // Output result to VTK file
@@ -175,53 +181,112 @@ void solvePoissonProblem()
   vtkWriter.addVertexData(pressureFunction, VTK::FieldInfo("pressure", VTK::FieldInfo::Type::scalar, 1));
   vtkWriter.write("testdunefunctionsgfs-poisson");
 
+  // Reassemble the Dirichlet constraints on the refined grid
+  PDELab::constraints(bctype,gfs,constraintsContainer);
 }
 
-template <class GridView>
-class StVenantKirchhoffParameters
-  : public Dune::PDELab::LinearElasticityParameterInterface<
-  Dune::PDELab::LinearElasticityParameterTraits<GridView, double>,
-  StVenantKirchhoffParameters<GridView> >
+void solveParallelPoissonProblem()
 {
-public:
-  typedef Dune::PDELab::LinearElasticityParameterTraits<GridView, double> Traits;
+  // read ini file
+  const int dim = 2;
+  const int refinement = 3;
+  const int degree = 1;
 
-  StVenantKirchhoffParameters(typename Traits::RangeFieldType l,
-                              typename Traits::RangeFieldType m) :
-    lambda_(l), mu_(m)
-  {}
+  // YaspGrid section
+  typedef YaspGrid<dim> GridType;
+  typedef GridType::ctype DF;
+  FieldVector<DF,dim> L = {1.0, 1.0};
+  std::array<int,dim> N = {16, 16};
+  std::bitset<dim> periodic(false);
+  int overlap=1;
+  GridType grid(L,N,periodic,overlap,MPIHelper::getCollectiveCommunication());
+  grid.refineOptions(false); // keep overlap in cells
+  grid.globalRefine(refinement);
+  using GV = GridType::LeafGridView;
+  GV gv=grid.leafGridView();
 
-  void f (const typename Traits::ElementType& e,
-          const typename Traits::DomainType& x,
-          typename Traits::RangeType & y) const
-  {
-    std::fill(y.begin(), y.end(), 1e5);
-  }
+  // make user functions
+  PoissonProblem<GV,double> problem;
+  auto glambda = [&](const auto& e, const auto& x){return problem.g(e,x);};
+  auto g = PDELab::makeGridFunctionFromCallable(gv,glambda);
+  auto blambda = [&](const auto& i, const auto& x){return problem.bctype(i,x);};
+  auto b = PDELab::makeBoundaryConditionFromCallable(gv,blambda);
 
-  template<typename I>
-  bool isDirichlet(const I & ig,
-                   const typename Traits::IntersectionDomainType & coord) const
-  {
-    return true;
-  }
+  // Make grid function space
+  typedef PDELab::OverlappingConformingDirichletConstraints CON; // NEW IN PARALLEL
+  typedef PDELab::ISTL::VectorBackend<> VBE;
 
-  typename Traits::RangeFieldType
-  lambda (const typename Traits::ElementType& e, const typename Traits::DomainType& x) const
-  {
-    return lambda_;
-  }
+  using Basis = Functions::LagrangeBasis<GV,degree>;
+  auto basis = std::make_shared<Basis>(gv);
 
-  typename Traits::RangeFieldType
-  mu (const typename Traits::ElementType& e, const typename Traits::DomainType& x) const
-  {
-    return mu_;
-  }
+  typedef PDELab::Experimental::GridFunctionSpace<Basis,
+                                                  VBE,
+                                                  CON> GridFunctionSpace;
+  GridFunctionSpace gridFunctionSpace(basis);
 
-private:
-  typename Traits::RangeFieldType lambda_;
-  typename Traits::RangeFieldType mu_;
-};
+  using FEM = GridFunctionSpace::Traits::FEM;
 
+  gridFunctionSpace.name("Vh");
+
+  // Assemble constraints
+  typedef typename GridFunctionSpace::template
+    ConstraintsContainer<double>::Type CC;
+  CC cc;
+  PDELab::constraints(b,gridFunctionSpace,cc); // assemble constraints
+
+  // A coefficient vector
+  using Z = PDELab::Backend::Vector<GridFunctionSpace,double>;
+  Z z(gridFunctionSpace); // initial value
+
+  // Make a grid function out of it
+  typedef PDELab::DiscreteGridFunction<GridFunctionSpace,Z> ZDGF;
+  ZDGF zdgf(gridFunctionSpace,z);
+
+  // Fill the coefficient vector
+  PDELab::interpolate(g,gridFunctionSpace,z);
+
+  // Make a local operator
+  typedef PDELab::ConvectionDiffusionFEM<decltype(problem),typename GridFunctionSpace::Traits::FiniteElementMap> LOP;
+  LOP lop(problem);
+
+  // Make a global operator
+  typedef PDELab::ISTL::BCRSMatrixBackend<> MBE;
+  MBE mbe((int)pow(1+2*degree,dim));
+  typedef PDELab::GridOperator<
+    GridFunctionSpace,  /* ansatz space */
+    GridFunctionSpace,  /* test space */
+    LOP,      /* local operator */
+    MBE,      /* matrix backend */
+    double,double,double, /* domain, range, jacobian field type*/
+    CC,CC     /* constraints for ansatz and test space */
+    > GO;
+  GO go(gridFunctionSpace,cc,gridFunctionSpace,cc,lop,mbe);
+
+  // Select a linear solver backend NEW IN PARALLEL
+  typedef PDELab::ISTLBackend_OVLP_CG_SSORk<GridFunctionSpace,CC> LS;
+  int verbose = 0;
+  LS ls(gridFunctionSpace,cc,100,5,verbose);
+
+  // solve nonlinear problem
+  PDELab::NewtonMethod<GO,LS> newton(go,ls);
+  Dune::ParameterTree newtonParam;
+  newtonParam["reassemble_threshold"] = "0.0";
+  newtonParam["verbosity"] = "2";
+  newtonParam["reduction"] = "1e-10";
+  newtonParam["min_linear_reduction"] = "1e-4";
+  newtonParam["terminate.max_iterations"] = "25";
+  newtonParam["line_search.line_search_max_iterations"] = "10";
+  newton.setParameters(newtonParam);
+  newton.apply(z);
+
+  // Write VTK output file
+  SubsamplingVTKWriter<GV> vtkwriter(gv,refinementIntervals(1));
+  typedef PDELab::VTKGridFunctionAdapter<ZDGF> VTKF;
+  vtkwriter.addVertexData(std::shared_ptr<VTKF>(new
+                                         VTKF(zdgf,"fesol")));
+  vtkwriter.write("pdelab-p-laplace-parallel-amd-result",
+                  VTK::appendedraw);
+}
 
 int main(int argc, char** argv) try
 {
@@ -232,6 +297,9 @@ int main(int argc, char** argv) try
   solvePoissonProblem<1>();
   solvePoissonProblem<2>();
 
+  // Test with a parallel setup
+  solveParallelPoissonProblem();
+
   return 0;
 }
 catch (Exception &e)
