@@ -15,17 +15,7 @@
 #include <dune/istl/preconditioners.hh>
 #include <dune/istl/operators.hh>
 
-#include <dune/pdelab/finiteelementmap/qkfem.hh>
-#include <dune/pdelab/constraints/conforming.hh>
-#include <dune/pdelab/gridfunctionspace/gridfunctionspace.hh>
-#include <dune/pdelab/gridfunctionspace/gridfunctionspaceutilities.hh>
-#include <dune/pdelab/gridfunctionspace/interpolate.hh>
-#include <dune/pdelab/common/function.hh>
-#include <dune/pdelab/backend/eigen.hh>
-#include <dune/pdelab/gridoperator/gridoperator.hh>
-#include <dune/pdelab/localoperator/convectiondiffusionfem.hh>
-#include <dune/pdelab/gridfunctionspace/vtk.hh>
-#include <dune/pdelab/stationary/linearproblem.hh>
+#include <dune/pdelab.hh>
 
 #include "gridexamples.hh"
 
@@ -50,6 +40,12 @@ class PoissonModelProblem
 public:
   typedef Dune::PDELab::ConvectionDiffusionParameterTraits<GV,RF> Traits;
 
+  //! tensor diffusion constant per cell? return false if you want more than one evaluation of A per cell.
+  static constexpr bool permeabilityIsConstantPerCell()
+  {
+    return true;
+  }
+
   //! tensor diffusion coefficient
   typename Traits::PermTensorType
   A (const typename Traits::ElementType& e, const typename Traits::DomainType& x) const
@@ -267,6 +263,19 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
     std::cout << "Time SLPSolver: " << timer.elapsed() << std::endl;
   }
 
+  // test the CG solver backend as part of a pdelab solver
+  {
+    Dune::Timer timer;
+    std::cout << "StationaryLinearProblemSolver" << std::endl;
+    typedef Dune::PDELab::EigenBackend_CG_Diagonal_Up LS;
+    LS linearSolver(5000);
+    x = 0.0;
+    Dune::PDELab::StationaryLinearProblemSolver<GridOperator,LS,DV> slp(gridoperator,linearSolver,x,1e-10);
+    slp.apply();
+    x += x0;
+    std::cout << "Time SLPSolver: " << timer.elapsed() << std::endl;
+  }
+
   // output grid function with VTKWriter
   Dune::VTKWriter<GV> vtkwriter(gv,Dune::VTK::conforming);
   Dune::PDELab::addSolutionToVTKWriter(vtkwriter,gfs,x);
