@@ -177,8 +177,8 @@ class WrappedFiniteElementMap
 public:
   using Traits = Dune::PDELab::LocalFiniteElementMapTraits<WrappedFiniteElement<T, k, d> >;
 
-  WrappedFiniteElementMap(const GV& gv_)
-      : gv(gv_)
+  WrappedFiniteElementMap(const GV& gv_, std::function<bool(std::size_t)> zeroPredicate_)
+      : gv(gv_), zeroPredicate(zeroPredicate_)
   {
   }
 
@@ -205,49 +205,100 @@ public:
   template <class EntityType>
   const typename Traits::FiniteElementType& find(const EntityType& e) const
   {
-    fe.setZero(gv.indexSet().index(e) % 2 == 0);
+    fe.setZero(zeroPredicate(gv.indexSet().index(e)));
     return fe;
   }
 
 private:
   mutable WrappedFiniteElement<T, k, d> fe;
   GV gv;
+  std::function<bool(std::size_t)> zeroPredicate;
 };
 
+/**
+ * check if the size of the ordering corresponds to the number of basis functions reported by the
+ * finite element map
+ */
+template <class GFS, class FEM>
+bool testSize(const GFS& gfs, const FEM& fem)
+{
+  std::cout << "ordering fixedSize: " << gfs.ordering().fixedSize() << "\n";
+  std::cout << "ordering size: " << gfs.ordering().size() << "\n";
+  std::cout << "ordering blockCount: " << gfs.ordering().blockCount() << "\n";
+
+  std::size_t size = 0;
+  for (const auto& e : Dune::elements(gfs.gridView())) {
+    size += fem.find(e).localBasis().size();
+  }
+  std::cout << "size by summing: " << size << "\n";
+
+  return size == gfs.ordering().size();
+}
+
+/**
+ * create a grid function space on a structured grid and test wether the size of the ordering is
+ * correct
+ */
+template <int dim>
+bool testPredicate(std::size_t cells, bool should_be_fixed_size,  std::function<bool(std::size_t)> predicate)
+{
+  Dune::FieldVector<double, dim> L(1.0);
+  std::array<int, dim> N(Dune::filledArray<dim, int>(cells));
+  Dune::YaspGrid<dim> grid(L, N);
+
+  using GV = typename Dune::YaspGrid<dim>::LeafGridView;
+  using FEM = WrappedFiniteElementMap<GV, double, 1, dim>;
+  using GFS = Dune::PDELab::GridFunctionSpace<GV, FEM>;
+
+  GV gv = grid.leafGridView();
+  FEM fem(gv, predicate);
+  GFS gfs(gv, fem);
+  gfs.update();
+  return testSize(gfs, fem) and gfs.ordering().fixedSize() == should_be_fixed_size;
+}
+
 int main(int argc, char** argv)
 {
   try {
     // Maybe initialize Mpi
     Dune::MPIHelper::instance(argc, argv);
 
-    Dune::FieldVector<double, 2> L(1.0);
-    std::array<int, 2> N(Dune::filledArray<2, int>(2));
-    Dune::YaspGrid<2> grid(L, N);
+    const std::size_t cells = 15;
 
-    using GV = Dune::YaspGrid<2>::LeafGridView;
-    using FEM = WrappedFiniteElementMap<GV, double, 1, 2>;
-    using GFS = Dune::PDELab::GridFunctionSpace<GV, FEM>;
-
-    GV gv = grid.leafGridView();
-    FEM fem(gv);
-    GFS gfs(gv, fem);
-    gfs.update();
-
-    std::cout << "ordering fixedSize: " << gfs.ordering().fixedSize(0) << "\n";
-    std::cout << "ordering size: " << gfs.ordering().size() << "\n";
-    std::cout << "ordering blockCount: " << gfs.ordering().blockCount() << "\n";
-
-    std::size_t size = 0;
-    for (const auto& e : Dune::elements(gv)) {
-      size += fem.find(e).localBasis().size();
-    }
-    std::cout << "size by summing: " << size << "\n";
-
-    if (size == gfs.ordering().size()) {
-      return 0;
-    } else {
+    // In these two basic scenarios, PDELab should detect that the ordering actually is fixed
+    // size and switch to fixed size mode after collecting the size information
+    std::cout << "testing 2D all cells active" << std::endl;
+    if (!testPredicate<2>(cells, true, [](auto i) { return true; })) {
       return -1;
     }
+    std::cout << "testing 2D all cells disabled" << std::endl;
+    if (!testPredicate<2>(cells, true, [](auto i) { return false; })) {
+      return -1;
+    }
+
+
+    // in the following we test different scenarios of a grid function space with a finite element
+    // that has 0 or c number of DOFs on different entities, where c is a constant. Wether an entity
+    // has 0 DOFs is determined by the predicates provided below.
+
+    std::cout << "testing 1D alternating sizes" << std::endl;
+    if (!testPredicate<1>(cells, false, [](auto i) { return i % 2 == 0; })) {
+      return -1;
+    }
+    std::cout << "testing 2D alternating sizes" << std::endl;
+    if (!testPredicate<2>(cells, false, [](auto i) { return i % 2 == 0; })) {
+      return -1;
+    }
+    std::cout << "testing 1D empty fem at the end" << std::endl;
+    if (!testPredicate<1>(cells, false, [cells](auto i) { return i > cells / 2; })) {
+      return -1;
+    }
+    std::cout << "testing 1D empty fem at the beginning" << std::endl;
+    if (!testPredicate<1>(cells, false, [cells](auto i) { return i <= cells / 2; })) {
+      return -1;
+    }
+    return 0;
+
   } catch (Dune::Exception& e) {
     std::cerr << "Dune reported error: " << e << std::endl;
     return 1;
