@@ -10,12 +10,7 @@
 #include <dune/common/parallel/mpihelper.hh>
 #include <dune/grid/yaspgrid.hh>
 
-#include <dune/pdelab/backend/istl.hh>
-#include <dune/pdelab/finiteelementmap/qkfem.hh>
-#include <dune/pdelab/gridfunctionspace/gridfunctionspace.hh>
-#include <dune/pdelab/gridfunctionspace/localvector.hh>
-#include <dune/pdelab/gridfunctionspace/subspace.hh>
-
+#include <dune/pdelab.hh>
 
 // test function trees
 template<class GV>
@@ -79,7 +74,7 @@ void test (const GV& gv)
   //CompositeLFSCache compositelfsCache(compositelfs);
   //  std::vector<double> xlc(compositelfs.maxSize());
 
-  typedef Dune::TypeTree::TreePath<1> Path1;
+  typedef Dune::TypeTree::StaticTreePath<1> Path1;
   typedef Dune::PDELab::GridFunctionSubSpace<CompositeGFS, Path1> SubGFS1;
   typedef Dune::PDELab::LocalFunctionSpace<SubGFS1> SubLFS1;
   SubGFS1 subgfs1(compositegfs);
